==> compass-client-0.1.116-sources.jar: com/xforceplus/ultraman/app/compass/controller/YearBillMainFeignApi.java <==
package com.xforceplus.ultraman.app.compass.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-08-16
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.compass.entity.YearBillMain;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "compass")
public interface YearBillMainFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/yearBillMain/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param yearBillMain ${table.comment}
   * @return R
   */
  @PostMapping("/yearBillMain/add")
  public R save(@RequestBody YearBillMain yearBillMain);

  /**
   * 修改${table.comment}
   * @param yearBillMain ${table.comment}
   * @return R
   */
  @PostMapping("/yearBillMain/update")
  public R updateById(@RequestBody YearBillMain yearBillMain);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/yearBillMain/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> compass-client-0.1.222-sources.jar: com/xforceplus/ultraman/app/compass/controller/YearBillMainFeignApi.java <==
package com.xforceplus.ultraman.app.compass.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2025-09-23
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.compass.entity.YearBillMain;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "compass")
public interface YearBillMainFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/yearBillMain/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param yearBillMain ${table.comment}
   * @return R
   */
  @PostMapping("/yearBillMain/add")
  public R save(@RequestBody YearBillMain yearBillMain);

  /**
   * 修改${table.comment}
   * @param yearBillMain ${table.comment}
   * @return R
   */
  @PostMapping("/yearBillMain/update")
  public R updateById(@RequestBody YearBillMain yearBillMain);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/yearBillMain/del/{id}" )
  public R removeById(@PathVariable Long id);

}
